@@ -1,7 +1,4 @@
-from pathlib import Path
-from tempfile import TemporaryDirectory
 import functools
-import unittest
 
 
 def temps(opener):
@@ -24,11 +21,12 @@ def temps(opener):
     return temps_class
 
 
-class TestCase(unittest.TestCase):
-    def setUp(self):
-        self.td_context = TemporaryDirectory()
-        self.td = Path(self.td_context.__enter__())
-        self.filename = self.td / 'test.txt'
+class socket:
+    def __init__(self):
+        self.items = []
 
-    def tearDown(self):
-        self.td_context.__exit__(None, None, None)
+    def send(self, item):
+        self.items.append(item)
+
+    def recv(self):
+        pass
